@@ -103,6 +103,13 @@
           (filter string?
                   (list
                    (ly:format "mark /OutputFile (~a)" output-file)
+                   ;; Ghostscript's default level may change with future
+                   ;; releases, the current being 1.7 since 9.24. This
+                   ;; results in a warning when embedding the produced PDF
+                   ;; with XeTeX, which currently defaults to PDF 1.5.
+                   ;; Set a fixed version of 1.4, which is also the basis
+                   ;; of the standard PDF/A and has all features we need.
+                   "/CompatibilityLevel 1.4"
                    (if (not is-eps)
                        (ly:format "/PageSize [~$ ~$]" paper-width paper-height))
                    "(pdfwrite) finddevice putdeviceprops pop"
@@ -117,7 +124,7 @@
 
     (ly:message (_ "Converting to `~a'...\n") dest)
     ((if (ly:get-option 'gs-api) ly:gs-api ly:gs-cli)
-      (gs-cmd-args is-eps #f) (string-join run-strings " "))
+     (gs-cmd-args is-eps #f) (string-join run-strings " "))
 
     ;; for pdfwrite, the output is only finalized once a new output
     ;; file is opened.
@@ -132,7 +139,7 @@
                        "(pdfwrite) selectdevice"
                        ;; see above
                        "newpath fill")
-                       " "))
+                      " "))
           (delete-file flush-name)))
 
     (ly:rename-file pdf-name dest)
@@ -274,7 +281,7 @@
 
               (make-tmpfile basename (1- tries))))
 
-        (ly:error "can't create temp file for ~a after ~a times" basename max-try)
+        (ly:error (_ "can't create temp file for ~a after ~a times") basename max-try)
         ))
 
   (if (not basename)
